<?php

// Add our field to the comment form
add_action ('comment_form', 'ning_update_comment_form');

// Add our sign in verification code
add_action ('preprocess_comment', 'ning_preprocess_comment');

// Add our sign in verification code
add_action ('comment_post', 'ning_comment_post');


// Add filter to retrieve the Ning avatar from the comment's meta data
add_filter ('get_avatar', 'ning_get_avatar', 10, 5);


function ning_update_comment_form() {
    if (!is_user_logged_in()) {
        $commenter = wp_get_current_commenter ();
        $comment_author = esc_attr($commenter['comment_author']);
        $comment_author_email = $commenter['comment_author_email'];
        $comment_author_url = $commenter['comment_author_url'];

        if (isset($_COOKIE['ning_avatar'])) {
?>
            <p><?php printf(__("Logged in as %s", 'ning-integration'), $comment_author) ?></p>
            <p><input type="hidden" name="author" id="author" class="textarea" value="<?php esc_attr($comment_author) ?>" /></p>
<?php
        } else {

            if (get_option('ning_anon_comments_setting') == 1) {
?>
<p>
<input type="text" name="author" id="author" class="textarea" value="<?php echo esc_attr($comment_author); ?>" size="28" tabindex="1" />
<label for="author"><small><?php _e("Name", 'ning-integration') ?></small></label>
</p>
<?php
            } else {
?>
            <p><input type="hidden" name="author" id="author" class="textarea" value="author" /></p>
<?php
            }
        }

        if (isset($_COOKIE['ning_avatar'])) {
?>
<input type="hidden" name="email" id="email" value="<?php echo esc_attr($comment_author_email); ?>" size="28" tabindex="2" />
<?php
        } else {
?>
    <p><input type="text" name="email" id="email" value="" size="22" tabindex="1" aria-required="true" />
    <label for="email"><small><?php _e("Email (will not be published) (required)", 'ning-integration') ?></small></label></p>

    <p><input type="password" name="pass" id="pass" size="22" tabindex="2" aria-required="true" />
    <label for="pass"><small><?php _e("Passsword (will not be published) (required)", 'ning-integration') ?></small></label></p>

<?php      } ?>

<p><input type="text" name="url" id="url" value="<?php echo esc_attr($comment_author_url); ?>" size="22" tabindex="3" />
<label for="url"><small><?php _e("Website", 'ning-integration') ?></small></label></p>
<?php
    }
}

function ning_preprocess_comment ($commentdata) {
    // TODO: find a better way of passing the member's avatar to ning_comment_post
    global $ning_avatar;

    // If the user is signed in, don't authorize against Ning
    if (is_user_logged_in()) { return $commentdata; };

    if (isset($_COOKIE['ning_avatar'])) {
        $ning_avatar = $_COOKIE['ning_avatar'];
    } else {
        // Collect the information needed for the authorization
        $ning_domain = get_option('ning_domain_setting');
        $comment_author_email = ( isset($_POST['email']) ) ? trim($_POST['email']) : null;
        $comment_author_pass = ( isset($_POST['pass']) ) ? trim($_POST['pass']) : null;

        // Die if we don't have the correct domain
        if (!$ning_domain) {
            wp_die( _e('Error: the administrator needs to configure the Ning Network\'s URL.') );
        }

        // Die if we don't have the correct credentials
        if (!$comment_author_email || !$comment_author_pass) {
            if (get_option('ning_anon_comments_setting') == 1) {
                return $commentdata;
            } else {
                wp_die( _e('Error: please fill the required fields (email, password).') );
            }
        }

        $user_info = NingIdApi::authorize ($ning_domain, $comment_author_email, $comment_author_pass);

        if (!$user_info) {
            wp_die( _e('Error: unable to verifiy your information, please check your email and password.') );
        }

        // Update the comment's author name with the name from the network if we have the form hidden
        if (get_option('ning_anon_comments_setting') == 1) {
            $commentdata['comment_author'] = $user_info['name'];
        }

        // remove query parameter from the avatar URL
        $url_parts = parse_url($user_info['avatar_url']);
        unset($url_parts['query']);
        unset($url_parts['fragment']);
        $ning_avatar = $url_parts['scheme'] . "://" . $url_parts['host'] . $url_parts['path'];

        // This is the cleaner way if you have the pecl_http PHP extension installed
        // $ning_avatar = http_build_url ($user_info['avatar_url'], null, HTTP_URL_STRIP_QUERY | HTTP_URL_STRIP_FRAGMENT);

        // Save the ning_avatar for later use
        setcookie ('ning_avatar', $ning_avatar, time()+60*60*24*30);

    }

	return $commentdata;
}

function ning_comment_post ($comment_ID) {
    // TODO: find a better way of passing the member's avatar to ning_comment_post
    global $ning_avatar;
    if ($ning_avatar) {
        // store the avatar in the comments meta data
        if (!add_comment_meta ($comment_ID, 'ning_avatar', $ning_avatar, true)) {
            wp_die("unable to create meta");
        }
    }
}

function ning_get_avatar ($avatar, $id_or_email, $size, $default, $alt) {
    global $comment;

    // Are we dealing with a comment?
    if ($comment) {
        $ning_avatar = get_comment_meta($comment->comment_ID, 'ning_avatar', true);

        // Does this comment have Ning avatar?
        if ($ning_avatar) {

            if ($size) {
                $query_string = http_build_query(array('width' => $size, 'height' => $size, 'crop' => '1:1'));
                $out = $ning_avatar . "?" . $query_string;
            } else {
                $out = $ning_avatar;
            }

            $avatar = "<img alt='{$alt}' src='{$out}' class='avatar avatar-{$size} photo' height='{$size}' width='{$size}' />";
        }
    }

    return $avatar;
}

